You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2012/03/28 18:25:28 UTC

svn commit: r1306455 - in /commons/proper/codec/trunk/src/main/java/org/apache/commons/codec: binary/ language/ net/

Author: ggregory
Date: Wed Mar 28 16:25:28 2012
New Revision: 1306455

URL: http://svn.apache.org/viewvc?rev=1306455&view=rev
Log:
Reanme "pString" to "

Modified:
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodec.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Caverphone.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Metaphone.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Nysiis.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/RefinedSoundex.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Soundex.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QCodec.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QuotedPrintableCodec.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodec.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodec.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodec.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodec.java Wed Mar 28 16:25:28 2012
@@ -258,17 +258,17 @@ public abstract class BaseNCodec impleme
      * Encodes an Object using the Base-N algorithm. This method is provided in order to satisfy the requirements of the
      * Encoder interface, and will throw an EncoderException if the supplied object is not of type byte[].
      *
-     * @param pObject
+     * @param obj
      *            Object to encode
      * @return An object (of type byte[]) containing the Base-N encoded data which corresponds to the byte[] supplied.
      * @throws EncoderException
      *             if the parameter supplied is not of type byte[]
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (!(pObject instanceof byte[])) {
+    public Object encode(Object obj) throws EncoderException {
+        if (!(obj instanceof byte[])) {
             throw new EncoderException("Parameter supplied to Base-N encode is not a byte[]");
         }
-        return encode((byte[]) pObject);
+        return encode((byte[]) obj);
     }
 
     /**
@@ -286,17 +286,17 @@ public abstract class BaseNCodec impleme
      * Decodes an Object using the Base-N algorithm. This method is provided in order to satisfy the requirements of the
      * Decoder interface, and will throw a DecoderException if the supplied object is not of type byte[] or String.
      *
-     * @param pObject
+     * @param obj
      *            Object to decode
      * @return An object (of type byte[]) containing the binary data which corresponds to the byte[] or String supplied.
      * @throws DecoderException
      *             if the parameter supplied is not of type byte[]
      */
-    public Object decode(Object pObject) throws DecoderException {        
-        if (pObject instanceof byte[]) {
-            return decode((byte[]) pObject);
-        } else if (pObject instanceof String) {
-            return decode((String) pObject);
+    public Object decode(Object obj) throws DecoderException {        
+        if (obj instanceof byte[]) {
+            return decode((byte[]) obj);
+        } else if (obj instanceof String) {
+            return decode((String) obj);
         } else {
             throw new DecoderException("Parameter supplied to Base-N decode is not a byte[] or a String");
         }

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Caverphone.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Caverphone.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Caverphone.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Caverphone.java Wed Mar 28 16:25:28 2012
@@ -62,29 +62,29 @@ public class Caverphone implements Strin
      * Encodes an Object using the caverphone algorithm. This method is provided in order to satisfy the requirements of
      * the Encoder interface, and will throw an EncoderException if the supplied object is not of type java.lang.String.
      * 
-     * @param pObject
+     * @param obj
      *            Object to encode
      * @return An object (or type java.lang.String) containing the caverphone code which corresponds to the String
      *         supplied.
      * @throws EncoderException
      *             if the parameter supplied is not of type java.lang.String
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (!(pObject instanceof String)) {
+    public Object encode(Object obj) throws EncoderException {
+        if (!(obj instanceof String)) {
             throw new EncoderException("Parameter supplied to Caverphone encode is not of type java.lang.String");
         }
-        return this.caverphone((String) pObject);
+        return this.caverphone((String) obj);
     }
 
     /**
      * Encodes a String using the Caverphone algorithm.
      * 
-     * @param pString
+     * @param str
      *            String object to encode
      * @return The caverphone code corresponding to the String supplied
      */
-    public String encode(String pString) {
-        return this.caverphone(pString);
+    public String encode(String str) {
+        return this.caverphone(str);
     }
 
     /**

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Metaphone.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Metaphone.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Nysiis.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Nysiis.java Wed Mar 28 16:25:28 2012
@@ -198,7 +198,7 @@ public class Nysiis implements StringEnc
      * Encoder interface, and will throw an {@link EncoderException} if the supplied object is not of type
      * {@link String}.
      *
-     * @param pObject
+     * @param obj
      *            Object to encode
      * @return An object (or a {@link String}) containing the NYSIIS code which corresponds to the given String.
      * @throws EncoderException
@@ -206,24 +206,24 @@ public class Nysiis implements StringEnc
      * @throws IllegalArgumentException
      *            if a character is not mapped
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (!(pObject instanceof String)) {
+    public Object encode(Object obj) throws EncoderException {
+        if (!(obj instanceof String)) {
             throw new EncoderException("Parameter supplied to Nysiis encode is not of type java.lang.String");
         }
-        return this.nysiis((String) pObject);
+        return this.nysiis((String) obj);
     }
 
     /**
      * Encodes a String using the NYSIIS algorithm.
      *
-     * @param pString
+     * @param str
      *            A String object to encode
      * @return A Nysiis code corresponding to the String supplied
      * @throws IllegalArgumentException
      *            if a character is not mapped
      */
-    public String encode(String pString) {
-        return this.nysiis(pString);
+    public String encode(String str) {
+        return this.nysiis(str);
     }
 
     /**

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/RefinedSoundex.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/RefinedSoundex.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/RefinedSoundex.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/RefinedSoundex.java Wed Mar 28 16:25:28 2012
@@ -121,29 +121,29 @@ public class RefinedSoundex implements S
      * and will throw an EncoderException if the supplied object is not of type
      * java.lang.String.
      * 
-     * @param pObject
+     * @param obj
      *                  Object to encode
      * @return An object (or type java.lang.String) containing the refined
      *             soundex code which corresponds to the String supplied.
      * @throws EncoderException
      *                  if the parameter supplied is not of type java.lang.String
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (!(pObject instanceof String)) {
+    public Object encode(Object obj) throws EncoderException {
+        if (!(obj instanceof String)) {
             throw new EncoderException("Parameter supplied to RefinedSoundex encode is not of type java.lang.String");
         }
-        return soundex((String) pObject);
+        return soundex((String) obj);
     }
 
     /**
      * Encodes a String using the refined soundex algorithm.
      * 
-     * @param pString
+     * @param str
      *                  A String object to encode
      * @return A Soundex code corresponding to the String supplied
      */
-    public String encode(String pString) {
-        return soundex(pString);
+    public String encode(String str) {
+        return soundex(str);
     }
 
     /**

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Soundex.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Soundex.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Soundex.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Soundex.java Wed Mar 28 16:25:28 2012
@@ -133,7 +133,7 @@ public class Soundex implements StringEn
      * Encodes an Object using the soundex algorithm. This method is provided in order to satisfy the requirements of
      * the Encoder interface, and will throw an EncoderException if the supplied object is not of type java.lang.String.
      * 
-     * @param pObject
+     * @param obj
      *                  Object to encode
      * @return An object (or type java.lang.String) containing the soundex code which corresponds to the String
      *             supplied.
@@ -142,24 +142,24 @@ public class Soundex implements StringEn
      * @throws IllegalArgumentException
      *                  if a character is not mapped
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (!(pObject instanceof String)) {
+    public Object encode(Object obj) throws EncoderException {
+        if (!(obj instanceof String)) {
             throw new EncoderException("Parameter supplied to Soundex encode is not of type java.lang.String");
         }
-        return soundex((String) pObject);
+        return soundex((String) obj);
     }
 
     /**
      * Encodes a String using the soundex algorithm.
      * 
-     * @param pString
+     * @param str
      *                  A String object to encode
      * @return A Soundex code corresponding to the String supplied
      * @throws IllegalArgumentException
      *                  if a character is not mapped
      */
-    public String encode(String pString) {
-        return soundex(pString);
+    public String encode(String str) {
+        return soundex(str);
     }
 
     /**

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QCodec.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QCodec.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Metaphone.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Metaphone.java Wed Mar 28 16:25:28 2012
@@ -357,27 +357,27 @@ public class Metaphone implements String
      * Encoder interface, and will throw an EncoderException if the
      * supplied object is not of type java.lang.String.
      *
      * @param pObject Object to encode
      * @return An object (or type java.lang.String) containing the 
      *         metaphone code which corresponds to the String supplied.
      * @throws EncoderException if the parameter supplied is not
      *                          of type java.lang.String
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (!(pObject instanceof String)) {
+    public Object encode(Object obj) throws EncoderException {
+        if (!(obj instanceof String)) {
             throw new EncoderException("Parameter supplied to Metaphone encode is not of type java.lang.String"); 
         }
-        return metaphone((String) pObject);
+        return metaphone((String) obj);
     }
 
     /**
      * Encodes a String using the Metaphone algorithm. 
      *
      * @param pString String object to encode
      * @return The metaphone code corresponding to the String supplied
      */
-    public String encode(String pString) {
-        return metaphone(pString);   
+    public String encode(String str) {
+        return metaphone(str);   
     }
 
     /**
@@ -357,27 +357,27 @@ public class Metaphone implements String
      * supplied object is not of type java.lang.String.
      *
-     * @param pObject Object to encode
+     * @param obj Object to encode
      * @return An object (or type java.lang.String) containing the 
      *         metaphone code which corresponds to the String supplied.
@@ -357,27 +357,27 @@ public class Metaphone implements String
      * Encodes a String using the Metaphone algorithm. 
      *
-     * @param pString String object to encode
+     * @param str String object to encode
      * @return The metaphone code corresponding to the String supplied
      */

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Nysiis.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/Nysiis.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QCodec.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QCodec.java Wed Mar 28 16:25:28 2012
@@ -193,40 +193,40 @@ public class QCodec extends RFC1522Codec
     /**
      * Encodes a string into its quoted-printable form using the specified charset. Unsafe characters are escaped.
      * 
-     * @param pString
+     * @param str
      *                  string to convert to quoted-printable form
      * @param charset
      *                  the charset for pString
      * @return quoted-printable string
      * 
      * @throws EncoderException
      *                  thrown if a failure condition is encountered during the encoding process.
      */
-    public String encode(final String pString, final Charset charset) throws EncoderException {
-        if (pString == null) {
+    public String encode(final String str, final Charset charset) throws EncoderException {
+        if (str == null) {
             return null;
         }
-        return encodeText(pString, charset);
+        return encodeText(str, charset);
     }
 
     /**
      * Encodes a string into its quoted-printable form using the specified charset. Unsafe characters are escaped.
      * 
-     * @param pString
+     * @param str
      *                  string to convert to quoted-printable form
      * @param charset
      *                  the charset for pString
      * @return quoted-printable string
      * 
      * @throws EncoderException
      *                  thrown if a failure condition is encountered during the encoding process.
      */
-    public String encode(final String pString, final String charset) throws EncoderException {
-        if (pString == null) {
+    public String encode(final String str, final String charset) throws EncoderException {
+        if (str == null) {
             return null;
         }
         try {
-            return encodeText(pString, charset);
+            return encodeText(str, charset);
         } catch (UnsupportedEncodingException e) {
             throw new EncoderException(e.getMessage(), e);
         }
@@ -235,25 +235,25 @@ public class QCodec extends RFC1522Codec
     /**
      * Encodes a string into its quoted-printable form using the default charset. Unsafe characters are escaped.
      * 
-     * @param pString
+     * @param str
      *                  string to convert to quoted-printable form
      * @return quoted-printable string
      * 
      * @throws EncoderException
      *                  thrown if a failure condition is encountered during the encoding process.
      */
-    public String encode(String pString) throws EncoderException {
-        if (pString == null) {
+    public String encode(String str) throws EncoderException {
+        if (str == null) {
             return null;
         }
-        return encode(pString, getCharset());
+        return encode(str, getCharset());
     }
 
     /**
      * Decodes a quoted-printable string into its original form. Escaped characters are converted back to their original
      * representation.
      * 
-     * @param pString
+     * @param str
      *                  quoted-printable string to convert into its original form
      * 
      * @return original string
@@ -261,12 +261,12 @@ public class QCodec extends RFC1522Codec
      * @throws DecoderException
      *                  A decoder exception is thrown if a failure condition is encountered during the decode process.
      */
-    public String decode(String pString) throws DecoderException {
-        if (pString == null) {
+    public String decode(String str) throws DecoderException {
+        if (str == null) {
             return null;
         }
         try {
-            return decodeText(pString);
+            return decodeText(str);
         } catch (UnsupportedEncodingException e) {
             throw new DecoderException(e.getMessage(), e);
         }
@@ -275,21 +275,21 @@ public class QCodec extends RFC1522Codec
     /**
      * Encodes an object into its quoted-printable form using the default charset. Unsafe characters are escaped.
      * 
-     * @param pObject
+     * @param obj
      *                  object to convert to quoted-printable form
      * @return quoted-printable object
      * 
      * @throws EncoderException
      *                  thrown if a failure condition is encountered during the encoding process.
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (pObject == null) {
+    public Object encode(Object obj) throws EncoderException {
+        if (obj == null) {
             return null;
-        } else if (pObject instanceof String) {
-            return encode((String) pObject);
+        } else if (obj instanceof String) {
+            return encode((String) obj);
         } else {
             throw new EncoderException("Objects of type " + 
-                  pObject.getClass().getName() + 
+                  obj.getClass().getName() + 
                   " cannot be encoded using Q codec");
         }
     }
@@ -298,7 +298,7 @@ public class QCodec extends RFC1522Codec
      * Decodes a quoted-printable object into its original form. Escaped characters are converted back to their original
      * representation.
      * 
-     * @param pObject
+     * @param obj
      *                  quoted-printable object to convert into its original form
      * 
      * @return original object
@@ -307,14 +307,14 @@ public class QCodec extends RFC1522Codec
      *                  Thrown if the argument is not a <code>String</code>. Thrown if a failure condition is
      *                  encountered during the decode process.
      */
-    public Object decode(Object pObject) throws DecoderException {
-        if (pObject == null) {
+    public Object decode(Object obj) throws DecoderException {
+        if (obj == null) {
             return null;
-        } else if (pObject instanceof String) {
-            return decode((String) pObject);
+        } else if (obj instanceof String) {
+            return decode((String) obj);
         } else {
             throw new DecoderException("Objects of type " + 
-                  pObject.getClass().getName() + 
+                  obj.getClass().getName() + 
                   " cannot be decoded using Q codec");
         }
     }
@@ -193,40 +193,40 @@ public class QCodec extends RFC1522Codec
      *                  string to convert to quoted-printable form
      * @param charset
-     *                  the charset for pString
+     *                  the charset for str
      * @return quoted-printable string
      * 
@@ -193,40 +193,40 @@ public class QCodec extends RFC1522Codec
      *                  string to convert to quoted-printable form
      * @param charset
-     *                  the charset for pString
+     *                  the charset for str
      * @return quoted-printable string
      * 

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QuotedPrintableCodec.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QuotedPrintableCodec.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QuotedPrintableCodec.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/QuotedPrintableCodec.java Wed Mar 28 16:25:28 2012
@@ -256,7 +256,7 @@ public class QuotedPrintableCodec implem
      * RFC 1521 and is suitable for encoding binary data.
      * </p>
      * 
-     * @param pString
+     * @param str
      *                  string to convert to quoted-printable form
      * @return quoted-printable string
      * 
@@ -265,15 +265,15 @@ public class QuotedPrintableCodec implem
      * 
      * @see #getCharset()
      */
-    public String encode(String pString) throws EncoderException {
-        return this.encode(pString, getCharset());
+    public String encode(String str) throws EncoderException {
+        return this.encode(str, getCharset());
     }
 
     /**
      * Decodes a quoted-printable string into its original form using the specified string charset. Escaped characters
      * are converted back to their original representation.
      * 
-     * @param pString
+     * @param str
      *                  quoted-printable string to convert into its original form
      * @param charset
      *                  the original string charset
@@ -281,18 +281,18 @@ public class QuotedPrintableCodec implem
      * @throws DecoderException
      *                  Thrown if quoted-printable decoding is unsuccessful
      */
-    public String decode(String pString, Charset charset) throws DecoderException {
-        if (pString == null) {
+    public String decode(String str, Charset charset) throws DecoderException {
+        if (str == null) {
             return null;
         }
-        return new String(this.decode(StringUtils.getBytesUsAscii(pString)), charset);
+        return new String(this.decode(StringUtils.getBytesUsAscii(str)), charset);
     }
 
     /**
      * Decodes a quoted-printable string into its original form using the specified string charset. Escaped characters
      * are converted back to their original representation.
      * 
-     * @param pString
+     * @param str
      *                  quoted-printable string to convert into its original form
      * @param charset
      *                  the original string charset
@@ -302,18 +302,18 @@ public class QuotedPrintableCodec implem
      * @throws UnsupportedEncodingException
      *                  Thrown if charset is not supported
      */
-    public String decode(String pString, String charset) throws DecoderException, UnsupportedEncodingException {
-        if (pString == null) {
+    public String decode(String str, String charset) throws DecoderException, UnsupportedEncodingException {
+        if (str == null) {
             return null;
         }
-        return new String(decode(StringUtils.getBytesUsAscii(pString)), charset);
+        return new String(decode(StringUtils.getBytesUsAscii(str)), charset);
     }
 
     /**
      * Decodes a quoted-printable string into its original form using the default string charset. Escaped characters are
      * converted back to their original representation.
      * 
-     * @param pString
+     * @param str
      *                  quoted-printable string to convert into its original form
      * @return original string
      * @throws DecoderException
@@ -321,30 +321,30 @@ public class QuotedPrintableCodec implem
      *                  Thrown if charset is not supported.
      * @see #getCharset()
      */
-    public String decode(String pString) throws DecoderException {
-        return this.decode(pString, this.getCharset());
+    public String decode(String str) throws DecoderException {
+        return this.decode(str, this.getCharset());
     }
 
     /**
      * Encodes an object into its quoted-printable safe form. Unsafe characters are escaped.
      * 
-     * @param pObject
+     * @param obj
      *                  string to convert to a quoted-printable form
      * @return quoted-printable object
      * @throws EncoderException
      *                  Thrown if quoted-printable encoding is not applicable to objects of this type or if encoding is
      *                  unsuccessful
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (pObject == null) {
+    public Object encode(Object obj) throws EncoderException {
+        if (obj == null) {
             return null;
-        } else if (pObject instanceof byte[]) {
-            return encode((byte[]) pObject);
-        } else if (pObject instanceof String) {
-            return encode((String) pObject);
+        } else if (obj instanceof byte[]) {
+            return encode((byte[]) obj);
+        } else if (obj instanceof String) {
+            return encode((String) obj);
         } else {
             throw new EncoderException("Objects of type " + 
-                  pObject.getClass().getName() + 
+                  obj.getClass().getName() + 
                   " cannot be quoted-printable encoded");
         }
     }
@@ -353,23 +353,23 @@ public class QuotedPrintableCodec implem
      * Decodes a quoted-printable object into its original form. Escaped characters are converted back to their original
      * representation.
      * 
-     * @param pObject
+     * @param obj
      *                  quoted-printable object to convert into its original form
      * @return original object
      * @throws DecoderException
      *                  Thrown if the argument is not a <code>String</code> or <code>byte[]</code>. Thrown if a failure condition is
      *                  encountered during the decode process.
      */
-    public Object decode(Object pObject) throws DecoderException {
-        if (pObject == null) {
+    public Object decode(Object obj) throws DecoderException {
+        if (obj == null) {
             return null;
-        } else if (pObject instanceof byte[]) {
-            return decode((byte[]) pObject);
-        } else if (pObject instanceof String) {
-            return decode((String) pObject);
+        } else if (obj instanceof byte[]) {
+            return decode((byte[]) obj);
+        } else if (obj instanceof String) {
+            return decode((String) obj);
         } else {
             throw new DecoderException("Objects of type " + 
-                  pObject.getClass().getName() + 
+                  obj.getClass().getName() + 
                   " cannot be quoted-printable decoded");
         }
     }
@@ -401,17 +401,17 @@ public class QuotedPrintableCodec implem
      * RFC 1521 and is suitable for encoding binary data and unformatted text.
      * </p>
      * 
-     * @param pString
+     * @param str
      *                  string to convert to quoted-printable form
      * @param charset
      *                  the charset for pString
      * @return quoted-printable string
      */
-    public String encode(String pString, Charset charset) {
-        if (pString == null) {
+    public String encode(String str, Charset charset) {
+        if (str == null) {
             return null;
         }
-        return StringUtils.newStringUsAscii(this.encode(pString.getBytes(charset)));
+        return StringUtils.newStringUsAscii(this.encode(str.getBytes(charset)));
     }
 
     /**
@@ -422,19 +422,19 @@ public class QuotedPrintableCodec implem
      * RFC 1521 and is suitable for encoding binary data and unformatted text.
      * </p>
      * 
-     * @param pString
+     * @param str
      *                  string to convert to quoted-printable form
      * @param charset
      *                  the charset for pString
      * @return quoted-printable string
      * 
      * @throws UnsupportedEncodingException
      *                  Thrown if the charset is not supported
      */
-    public String encode(String pString, String charset) throws UnsupportedEncodingException {
-        if (pString == null) {
+    public String encode(String str, String charset) throws UnsupportedEncodingException {
+        if (str == null) {
             return null;
         }
-        return StringUtils.newStringUsAscii(encode(pString.getBytes(charset)));
+        return StringUtils.newStringUsAscii(encode(str.getBytes(charset)));
     }
 }
@@ -401,17 +401,17 @@ public class QuotedPrintableCodec implem
      *                  string to convert to quoted-printable form
      * @param charset
-     *                  the charset for pString
+     *                  the charset for str
      * @return quoted-printable string
      */
@@ -422,19 +422,19 @@ public class QuotedPrintableCodec implem
      *                  string to convert to quoted-printable form
      * @param charset
-     *                  the charset for pString
+     *                  the charset for str
      * @return quoted-printable string
      * 

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java?rev=1306455&r1=1306454&r2=1306455&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/net/URLCodec.java Wed Mar 28 16:25:28 2012
@@ -214,37 +214,37 @@ public class URLCodec implements BinaryE
     /**
      * Encodes a string into its URL safe form using the specified string charset. Unsafe characters are escaped.
      * 
-     * @param pString
+     * @param str
      *            string to convert to a URL safe form
      * @param charset
      *            the charset for pString
      * @return URL safe string
      * @throws UnsupportedEncodingException
      *             Thrown if charset is not supported
      */
-    public String encode(String pString, String charset) throws UnsupportedEncodingException {
-        if (pString == null) {
+    public String encode(String str, String charset) throws UnsupportedEncodingException {
+        if (str == null) {
             return null;
         }
-        return StringUtils.newStringUsAscii(encode(pString.getBytes(charset)));
+        return StringUtils.newStringUsAscii(encode(str.getBytes(charset)));
     }
 
     /**
      * Encodes a string into its URL safe form using the default string 
      * charset. Unsafe characters are escaped.
      *
      * @param pString string to convert to a URL safe form
      * @return URL safe string
      * @throws EncoderException Thrown if URL encoding is unsuccessful
      * 
      * @see #getDefaultCharset()
      */
-    public String encode(String pString) throws EncoderException {
-        if (pString == null) {
+    public String encode(String str) throws EncoderException {
+        if (str == null) {
             return null;
         }
         try {
-            return encode(pString, getDefaultCharset());
+            return encode(str, getDefaultCharset());
         } catch (UnsupportedEncodingException e) {
             throw new EncoderException(e.getMessage(), e);
         }
@@ -256,18 +256,18 @@ public class URLCodec implements BinaryE
      * specified encoding. Escaped characters are converted back 
      * to their original representation.
      *
      * @param pString URL safe string to convert into its original form
      * @param charset the original string charset
      * @return original string 
      * @throws DecoderException Thrown if URL decoding is unsuccessful
      * @throws UnsupportedEncodingException Thrown if charset is not
      *                                      supported 
      */
-    public String decode(String pString, String charset) throws DecoderException, UnsupportedEncodingException {
-        if (pString == null) {
+    public String decode(String str, String charset) throws DecoderException, UnsupportedEncodingException {
+        if (str == null) {
             return null;
         }
-        return new String(decode(StringUtils.getBytesUsAscii(pString)), charset);
+        return new String(decode(StringUtils.getBytesUsAscii(str)), charset);
     }
 
     /**
@@ -275,18 +275,18 @@ public class URLCodec implements BinaryE
      * string charset. Escaped characters are converted back to their 
      * original representation.
      *
      * @param pString URL safe string to convert into its original form
      * @return original string 
      * @throws DecoderException Thrown if URL decoding is unsuccessful
      * 
      * @see #getDefaultCharset()
      */
-    public String decode(String pString) throws DecoderException {
-        if (pString == null) {
+    public String decode(String str) throws DecoderException {
+        if (str == null) {
             return null;
         }
         try {
-            return decode(pString, getDefaultCharset());
+            return decode(str, getDefaultCharset());
         } catch (UnsupportedEncodingException e) {
             throw new DecoderException(e.getMessage(), e);
         }
@@ -296,22 +296,22 @@ public class URLCodec implements BinaryE
      * Encodes an object into its URL safe form. Unsafe characters are 
      * escaped.
      *
      * @param pObject string to convert to a URL safe form
      * @return URL safe object
      * @throws EncoderException Thrown if URL encoding is not 
      *                          applicable to objects of this type or
      *                          if encoding is unsuccessful
      */
-    public Object encode(Object pObject) throws EncoderException {
-        if (pObject == null) {
+    public Object encode(Object obj) throws EncoderException {
+        if (obj == null) {
             return null;
-        } else if (pObject instanceof byte[]) {
-            return encode((byte[])pObject);
-        } else if (pObject instanceof String) {
-            return encode((String)pObject);
+        } else if (obj instanceof byte[]) {
+            return encode((byte[])obj);
+        } else if (obj instanceof String) {
+            return encode((String)obj);
         } else {
             throw new EncoderException("Objects of type " +
-                pObject.getClass().getName() + " cannot be URL encoded"); 
+                obj.getClass().getName() + " cannot be URL encoded"); 
               
         }
     }
@@ -320,22 +320,22 @@ public class URLCodec implements BinaryE
      * Decodes a URL safe object into its original form. Escaped characters are converted back to their original
      * representation.
      * 
-     * @param pObject
+     * @param obj
      *                  URL safe object to convert into its original form
      * @return original object
      * @throws DecoderException
      *                  Thrown if the argument is not a <code>String</code> or <code>byte[]</code>. Thrown if a failure condition is
      *                  encountered during the decode process.
      */
-    public Object decode(Object pObject) throws DecoderException {
-        if (pObject == null) {
+    public Object decode(Object obj) throws DecoderException {
+        if (obj == null) {
             return null;
-        } else if (pObject instanceof byte[]) {
-            return decode((byte[]) pObject);
-        } else if (pObject instanceof String) {
-            return decode((String) pObject);
+        } else if (obj instanceof byte[]) {
+            return decode((byte[]) obj);
+        } else if (obj instanceof String) {
+            return decode((String) obj);
         } else {
-            throw new DecoderException("Objects of type " + pObject.getClass().getName() + " cannot be URL decoded");
+            throw new DecoderException("Objects of type " + obj.getClass().getName() + " cannot be URL decoded");
 
         }
     }
@@ -214,37 +214,37 @@ public class URLCodec implements BinaryE
      *            string to convert to a URL safe form
      * @param charset
-     *            the charset for pString
+     *            the charset for str
      * @return URL safe string
      * @throws UnsupportedEncodingException
@@ -214,37 +214,37 @@ public class URLCodec implements BinaryE
      * charset. Unsafe characters are escaped.
      *
-     * @param pString string to convert to a URL safe form
+     * @param str string to convert to a URL safe form
      * @return URL safe string
      * @throws EncoderException Thrown if URL encoding is unsuccessful
@@ -256,18 +256,18 @@ public class URLCodec implements BinaryE
      * to their original representation.
      *
-     * @param pString URL safe string to convert into its original form
+     * @param str URL safe string to convert into its original form
      * @param charset the original string charset
      * @return original string 
@@ -275,18 +275,18 @@ public class URLCodec implements BinaryE
      * original representation.
      *
-     * @param pString URL safe string to convert into its original form
+     * @param str URL safe string to convert into its original form
      * @return original string 
      * @throws DecoderException Thrown if URL decoding is unsuccessful
@@ -296,22 +296,22 @@ public class URLCodec implements BinaryE
      * escaped.
      *
-     * @param pObject string to convert to a URL safe form
+     * @param obj string to convert to a URL safe form
      * @return URL safe object
      * @throws EncoderException Thrown if URL encoding is not 